﻿
namespace StoreDemo
{
	using Windows.ApplicationModel.Store;
	using Windows.UI.Popups;

	using System;
	using Windows.Storage;
	using Windows.UI.Xaml;
	using Windows.UI.Xaml.Controls;

#if !DEBUG  
		using StoreApp = Windows.ApplicationModel.Store.CurrentApp;
#else
		using StoreApp = Windows.ApplicationModel.Store.CurrentAppSimulator;
#endif

	/// <summary>
	/// An empty page that can be used on its own or navigated to within a Frame.
	/// </summary>
	public sealed partial class MainPage : Page
	{
		private ListingInformation appListings;

		private decimal usageCount;

		public MainPage()
		{
			this.InitializeComponent();
#if DEBUG
			this.LoadFakeStoreData();
#endif
		}

		private async void LoadFakeStoreData()
		{
			StorageFile file = await StorageFile.GetFileFromApplicationUriAsync(new Uri("ms-appx:///StoreSimulation.xml"));
			await StoreApp.ReloadSimulatorAsync(file);
			this.GetStoreInfo(this, null);
		}

		private async void GetStoreInfo(object sender, RoutedEventArgs e)
		{
			//A network connection is required...
			if (!this.IsConnectionAvailable) return;

			DataListBox.Items.Clear();
			DataListBox.Items.Add(string.Format("AppId: {0}", StoreApp.AppId));
			DataListBox.Items.Add(string.Format("Link: {0}", StoreApp.LinkUri));
			DataListBox.Items.Add(string.Format("IsActive: {0}", StoreApp.LicenseInformation.IsActive));
			DataListBox.Items.Add(string.Format("IsTrial: {0}", StoreApp.LicenseInformation.IsTrial));
			DataListBox.Items.Add(string.Format("ExpireDate: {0}", StoreApp.LicenseInformation.ExpirationDate));

			//Listing info
			try
			{
				this.appListings = await StoreApp.LoadListingInformationAsync();
				DataListBox.Items.Add(string.Format("Current Market: {0}", this.appListings.CurrentMarket));
				DataListBox.Items.Add(string.Format("Current Price: {0}", this.appListings.FormattedPrice));
				foreach (ProductListing prodListing in this.appListings.ProductListings.Values)
				{
					DataListBox.Items.Add(
						string.Format(
							"Product Name:{0} Type:{1} FormattedPrice:{2}",
							prodListing.Name,
							prodListing.ProductType,
							prodListing.FormattedPrice));
				}
			}
			catch (Exception ex)
			{
				DataListBox.Items.Add(ex.Message);
			}
		}

		private async void OnBuy(object sender, RoutedEventArgs e)
		{
			string receipt = null;
			string msg;
			if (!StoreApp.LicenseInformation.IsTrial)
			{
				msg = "No need to buy!";
			}
			else
			{
				try
				{
					// Prompt the user to purchase a license for the app
					bool createReceipt = true;
					receipt = await StoreApp.RequestAppPurchaseAsync(createReceipt);
					msg = StoreApp.LicenseInformation.IsActive ? "App license purchased" : "App license purchase cancelled";
				}
				catch (Exception ex)
				{
					msg = ex.Message;
				}
			}

			await new MessageDialog(msg).ShowAsync();

		}

		private void OnDurable(object sender, RoutedEventArgs e)
		{
			DataListBox.Items.Clear();

			ProductLicense mlnLicense = StoreApp.LicenseInformation.ProductLicenses["MontlyLocalNews"];
			ProductLicense bnLicense = StoreApp.LicenseInformation.ProductLicenses["BreakingNews"];

			DataListBox.Items.Add(string.Format("Local news -> IsActive:{0} ExpireDate:{1}", mlnLicense.IsActive, mlnLicense.ExpirationDate));
			DataListBox.Items.Add(string.Format("Breaking news -> IsActive:{0} ExpireDate:{1}", bnLicense.IsActive, bnLicense.ExpirationDate));
		}

		private async void BuyDurable(object sender, RoutedEventArgs e)
		{
			string receipt = null;
			string msg;

			//Let's buy Montly local news feature
			const string ProductId = "MontlyLocalNews";
			ProductLicense license = StoreApp.LicenseInformation.ProductLicenses[ProductId];

			if (license.IsActive)
			{
				msg = "Feature already active";
			}
			else
			{
				try
				{
					PurchaseResults result = await StoreApp.RequestProductPurchaseAsync(ProductId);
					msg = result.Status == ProductPurchaseStatus.Succeeded ? "Product purchased" : "Product license not purchased";
				}
				catch (Exception ex)
				{
					msg = ex.Message;
				}
			}

			await new MessageDialog(msg).ShowAsync();
		}

		private async void BuyConsumable(object sender, RoutedEventArgs e)
		{
			string receipt = null;
			string msg;

			//Let's buy Chat with editor on time product
			const string ProductId = "ChatWithEditor";

			try
			{
				PurchaseResults result = await StoreApp.RequestProductPurchaseAsync(ProductId);
				msg = result.Status == ProductPurchaseStatus.Succeeded ? "Consumable purchased" : "Consumable not purchased";
				switch (result.Status)
				{
					case ProductPurchaseStatus.Succeeded:
						this.usageCount++;
						FulfillmentResult fullFillResult = await StoreApp.ReportConsumableFulfillmentAsync(ProductId, result.TransactionId);
						switch (fullFillResult)
						{
							case FulfillmentResult.Succeeded:
								msg = "Product consumed, you can purchase it again.";
								break;
							case FulfillmentResult.NothingToFulfill:
								break;
							case FulfillmentResult.PurchasePending:
								break;
							case FulfillmentResult.PurchaseReverted:
								break;
							case FulfillmentResult.ServerError:
								break;
							default:
								throw new ArgumentOutOfRangeException();
						}

						break;
					case ProductPurchaseStatus.AlreadyPurchased:
						break;
					case ProductPurchaseStatus.NotFulfilled:
						msg = "Offer not yet used...";
						break;
					case ProductPurchaseStatus.NotPurchased:
						break;
					default:
						throw new ArgumentOutOfRangeException();
				}

				//TransactionI can be used to associate product use
				this.SaveConsumableProductInfo(result.TransactionId);
			}
			catch (Exception ex)
			{
				msg = ex.Message;
			}

			await new MessageDialog(msg).ShowAsync();
		}

		private void SaveConsumableProductInfo(Guid transactionId)
		{
			//ToDo...
		}

		private bool IsConnectionAvailable
		{
			get
			{
				return true;
			}
		}
	}
}
